@@ -11,7 +11,7 @@ from .models import EquipmentData
 class EquipmentDataFilterForm(CustomFieldModelFilterForm):
     model = EquipmentData
     region = DynamicModelChoiceField(
-        queryset=Region.objects.filter(name=0),
+        queryset=Region.objects.filter(level=0),
         required=False
     )
     city = DynamicModelChoiceField(
